<?php
/* speedMon_XH-1alpha2 
* copyright  2014 by manu @ www.pixolution.ch
* This plugin is free software and is subject 
*  to the same licence conditions as CMSimple is.
*/

    /**
     * Class for php perfomance monitoring
     *
     */
class SpeedMon {

    /**
     *
     * @private float  = 0: not yet started, negative value = completed measurement,
     * positive value = timestamp of start
     * 
     */
    
    private $measure = 0;
    
    /**
     * Checks if measurement has not started or already completed.
     *
     */
    public function notStarted() {
        return $this->measure <= 0;
    }

    /**
     * Start/continue measurement. Start timestamp ist corrected by previous measurement.
     *
     * @return void
     *
     */
    public function start() {
        $this->measure += microtime(true);
    }

    /**
     * Stops measurement and stores elapsed time.
     *
     * @return void
     */
    public function stop() {
        $this->measure = $this->measure - microtime(true);
    }

    /**
     * Checks if paramenter is an anonymous (callback) function (which implements a plugin call) like function(){pluginCall();}.
     *
     * @param object $func An anonymous function.
     *
     * @return bool
     */
    public static function isFunction($func) {
        return is_object($func) && is_a($func,'Closure');
    }

    /**
     * Parses array of monitored plugin calls.
     *
     * @param array $messungen All object of measurements.
     *
     * @return string HTML output
     *
     */
    public static function displayAll($messungen) {
        array_walk($messungen,function(&$messung) { 
            $messung = $messung->display();
        });    //style array for output
        return empty($messungen)? '' : '
<pre>
Speedmonitor:
'.print_r($messungen,true).'
</pre>
';
    }

    /**
     * Parses single measurement of encapsulated plugin function
     *
     * @return string HTML
     *
     */
    public function displayFunction() {
        return '
<pre>
Speedmonitor: '. $this->display().'
</pre>
';
    }

    /**
     * Formats single measurement 
     *
     * @return string formatted measurement.
     *
     */
    private function display() {
        return $this->measure <= 0 ? sprintf( "%0.2f millsecs",-$this->measure * 1000) : 'open';
    }
}
?>